@@ -19,10 +19,7 @@ def send_many(n):
     #: If hostname, userid, password and virtual_host is not specified
     #: the values below are the default, but listed here so it can
     #: be easily changed.
-    connection = BrokerConnection(hostname="localhost",
-                                  userid="guest",
-                                  password="guest",
-                                  virtual_host="/")
+    connection = BrokerConnection("amqp://guest:guest@localhost:5672//")
 
     #: SimpleQueue mimics the interface of the Python Queue module.
     #: First argument can either be a queue name or a kombu.Queue object.
@@ -38,5 +35,8 @@ def send_many(n):
         pool.spawn(send_message, i)
     pool.waitall()
 
+    queue.close()
+    connection.close()
+
 if __name__ == "__main__":
     send_many(10)
