@@ -3,7 +3,7 @@ from __future__ import with_statement
 from kombu.common import maybe_declare
 from kombu.pools import producers
 
-from .queues import task_exchange
+from queues import task_exchange
 
 priority_to_routing_key = {"high": "hipri",
                            "mid": "midpri",
@@ -22,8 +22,8 @@ def send_as_task(connection, fun, args, kwargs, priority="mid"):
 
 if __name__ == "__main__":
     from kombu import BrokerConnection
-    from .tasks import hello_task
+    from tasks import hello_task
 
     connection = BrokerConnection("amqp://guest:guest@localhost:5672//")
-    send_as_task(connection, fun=hello_task, args=("Kombu", ),
+    send_as_task(connection, fun=hello_task, args=("Kombu", ), kwargs={},
                  priority="high")
