@@ -8,11 +8,14 @@ from queues import task_queues
 
 class Worker(ConsumerMixin):
 
-    def get_consumers(self, Consumer, channel):
-        return Consumer(queues=task_queues,
-                        callbacks=[self.process_task])
+    def __init__(self, connection):
+        self.connection = connection
 
-    def process_task(body, message):
+    def get_consumers(self, Consumer, channel):
+        return [Consumer(queues=task_queues,
+                        callbacks=[self.process_task])]
+
+    def process_task(self, body, message):
         fun = body["fun"]
         args = body["args"]
         kwargs = body["kwargs"]
@@ -21,7 +24,7 @@ class Worker(ConsumerMixin):
 
 if __name__ == "__main__":
     from kombu import BrokerConnection
-    from kombu.log import setup_logging
+    from kombu.utils.debug import setup_logging
     setup_logging(loglevel="INFO")
 
     with BrokerConnection("amqp://guest:guest@localhost:5672//") as conn:
