@@ -4,7 +4,7 @@ kombu.compression
 
 Object utilities.
 
-:copyright: (c) 2009 - 2010 by Ask Solem.
+:copyright: (c) 2009 - 2011 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
@@ -30,9 +30,15 @@ class Object(object):
                 except AttributeError:
                     setattr(self, name, None)
 
+    def as_dict(self, recurse=False):
+        def f(obj):
+            if recurse and isinstance(obj, Object):
+                return obj.as_dict(recurse=True)
+            return obj
+        return dict((attr, f(getattr(self, attr))) for attr, _ in self.attrs)
+
     def __copy__(self):
-        return self.__class__(**dict((name, getattr(self, name))
-                                        for name, _ in self.attrs))
+        return self.__class__(**self.as_dict())
 
 
 class MaybeChannelBound(Object):
