@@ -134,6 +134,9 @@ class Exchange(MaybeChannelBound):
         self.type = type or self.type
         self.maybe_bind(channel)
 
+    def __hash__(self):
+        return hash("E|%s" % (self.name, ))
+
     def declare(self, nowait=False):
         """Declare the exchange.
 
@@ -323,6 +326,12 @@ class Queue(MaybeChannelBound):
 
         Additional arguments used when binding the queue.
 
+    .. attribute:: alias
+
+        Unused in Kombu, but application can take advantage of this.
+        For example to give alternate names to queues with automatically
+        generated queue names.
+
     """
     name = ""
     exchange = None
@@ -341,7 +350,8 @@ class Queue(MaybeChannelBound):
              ("durable", bool),
              ("exclusive", bool),
              ("auto_delete", bool),
-             ("no_ack", None))
+             ("no_ack", None),
+             ("alias", None))
 
     def __init__(self, name="", exchange=None, routing_key="", channel=None,
             **kwargs):
@@ -354,6 +364,9 @@ class Queue(MaybeChannelBound):
             self.auto_delete = True
         self.maybe_bind(channel)
 
+    def __hash__(self):
+        return hash("Q|%s" % (self.name, ))
+
     def when_bound(self):
         if self.exchange:
             self.exchange = self.exchange(self.channel)
