@@ -17,6 +17,8 @@ try:
 except ImportError:
     cpickle = None  # noqa
 
+from kombu.utils.encoding import str_to_bytes
+
 
 if sys.platform.startswith("java"):
 
@@ -146,6 +148,9 @@ class SerializerRegistry(object):
         except KeyError:
             return data
 
+        if not data:
+            return data
+
         return decoder(data)
 
 
@@ -293,7 +298,9 @@ def register_yaml():
 def register_pickle():
     """The fastest serialization method, but restricts
     you to python clients."""
-    registry.register('pickle', pickle.dumps, pickle.loads,
+    def deserialize(data):
+        return pickle.loads(str_to_bytes(data))
+    registry.register('pickle', pickle.dumps, deserialize,
                       content_type='application/x-python-serialize',
                       content_encoding='binary')
 
