@@ -4,7 +4,7 @@ kombu.simple
 
 Simple interface.
 
-:copyright: (c) 2009 - 2010 by Ask Solem.
+:copyright: (c) 2009 - 2011 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
@@ -21,6 +21,12 @@ from kombu import messaging
 class SimpleBase(object):
     _consuming = False
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *exc_info):
+        self.close()
+
     def __init__(self, channel, producer, consumer, no_ack=False,
             channel_autoclose=False):
         self.channel = channel
@@ -32,7 +38,7 @@ class SimpleBase(object):
         self.buffer = deque()
         self.consumer.register_callback(self._receive)
 
-    def get(self, block=True, timeout=None, sync=False):
+    def get(self, block=True, timeout=None):
         if not block:
             return self.get_nowait()
         self._consume()
@@ -48,7 +54,7 @@ class SimpleBase(object):
             except socket.timeout:
                 raise Empty()
             elapsed += time() - time_start
-            remaining = timeout - elapsed
+            remaining = timeout and timeout - elapsed or None
 
     def get_nowait(self):
         m = self.queue.get(no_ack=self.no_ack)
