@@ -1,4 +1,4 @@
-import unittest2 as unittest
+from kombu.tests.utils import unittest
 
 from kombu import transport
 
