@@ -97,9 +97,13 @@ class Message(object):
 
         """
         if self.channel.no_ack_consumers is not None:
-            consumer_tag = self.delivery_info["consumer_tag"]
-            if consumer_tag in self.channel.no_ack_consumers:
-                return
+            try:
+                consumer_tag = self.delivery_info["consumer_tag"]
+            except KeyError:
+                pass
+            else:
+                if consumer_tag in self.channel.no_ack_consumers:
+                    return
         if self.acknowledged:
             raise self.MessageStateError(
                 "Message already acknowledged with state: %s" % self._state)
