@@ -25,20 +25,26 @@ class Channel(virtual.Channel):
             self.queues[queue] = Queue()
 
     def _get(self, queue, timeout=None):
-        return self.queues[queue].get(block=False)
+        return self._queue_for(queue).get(block=False)
+
+    def _queue_for(self, queue):
+        if queue not in self.queues:
+            self.queues[queue] = Queue()
+        return self.queues[queue]
 
     def _put(self, queue, message, **kwargs):
-        self.queues[queue].put(message)
+        self._queue_for(queue).put(message)
 
     def _size(self, queue):
-        return self.queues[queue].qsize()
+        return self._queue_for(queue).qsize()
 
-    def _delete(self, queue):
+    def _delete(self, queue, *args):
         self.queues.pop(queue, None)
 
     def _purge(self, queue):
-        size = self.queues[queue].qsize()
-        self.queues[queue].queue.clear()
+        q = self._queue_for(queue)
+        size = q.qsize()
+        q.queue.clear()
         return size
 
     def after_reply_message_received(self, queue):
