@@ -23,7 +23,7 @@ from amqplib.client_0_8.exceptions import AMQPConnectionException
 from amqplib.client_0_8.exceptions import AMQPChannelException
 
 from kombu.transport import base
-from kombu.utils.compat import str_to_bytes
+from kombu.utils.encoding import str_to_bytes
 
 DEFAULT_PORT = 5672
 
