@@ -75,10 +75,15 @@ class Channel(virtual.Channel):
         server = couchdb.Server('%s://%s:%s/' % (proto,
                                                  conninfo.hostname,
                                                  port))
+        # Use username and password if avaliable
+        try:
+            server.resource.credentials = (conninfo.userid, conninfo.password)
+        except AttributeError:
+            pass
         try:
-            return server.create(dbname)
-        except couchdb.PreconditionFailed:
             return server[dbname]
+        except couchdb.http.ResourceNotFound:
+            return server.create(dbname)
 
     def _query(self, queue, **kwargs):
         if not self.view_created:
