@@ -138,12 +138,21 @@ class Channel(channel.Channel, base.StdChannel):
 
 
 class BlockingConnection(blocking_adapter.BlockingConnection):
+    Super = blocking_adapter.BlockingConnection
+
+    def __init__(self, client, *args, **kwargs):
+        self.client = client
+        self.Super.__init__(self, *args, **kwargs)
 
     def channel(self):
         c = Channel(channel.ChannelHandler(self))
         c.connection = self
         return c
 
+    def close(self):
+        self.client = None
+        self.Super.close(self)
+
     def ensure_drain_events(self, timeout=None):
         return self.drain_events(timeout=timeout)
 
@@ -152,6 +161,10 @@ class AsyncoreConnection(asyncore_adapter.AsyncoreConnection):
     _event_counter = 0
     Super = asyncore_adapter.AsyncoreConnection
 
+    def __init__(self, client, *args, **kwargs):
+        self.client = client
+        self.Super.__init__(self, *args, **kwargs)
+
     def channel(self):
         c = Channel(channel.ChannelHandler(self))
         c.connection = self
@@ -170,6 +183,10 @@ class AsyncoreConnection(asyncore_adapter.AsyncoreConnection):
         self._event_counter += 1
         self.Super.on_data_available(self, buf)
 
+    def close(self):
+        self.client = None
+        self.Super.close(self)
+
 
 class SyncTransport(base.Transport):
     default_port = DEFAULT_PORT
@@ -211,11 +228,11 @@ class SyncTransport(base.Transport):
                 setattr(conninfo, name, default_value)
         credentials = connection.PlainCredentials(conninfo.userid,
                                                   conninfo.password)
-        return self.Connection(connection.ConnectionParameters(
-                                        conninfo.hostname,
-                                        port=conninfo.port,
-                                        virtual_host=conninfo.virtual_host,
-                                        credentials=credentials))
+        return self.Connection(self.client,
+                               connection.ConnectionParameters(
+                                    conninfo.hostname, port=conninfo.port,
+                                    virtual_host=conninfo.virtual_host,
+                                    credentials=credentials))
 
     def close_connection(self, connection):
         """Close the AMQP broker connection."""
