@@ -32,13 +32,13 @@ class ExchangeType(object):
         raise NotImplementedError("subclass responsibility")
 
     def prepare_bind(self, queue, exchange, routing_key, arguments):
-        """:returns: `(routing_key, regex, queue)` tuple to store
+        """Returns tuple of `(routing_key, regex, queue)` to be stored
         for bindings to this exchange."""
         return routing_key, None, queue
 
     def equivalent(self, prev, exchange, type, durable, auto_delete,
             arguments):
-        """Returns true if `prev` and `*exchange* is equivalent."""
+        """Returns true if `prev` and `exchange` is equivalent."""
         return (type == prev["type"] and
                 durable == prev["durable"] and
                 auto_delete == prev["auto_delete"] and
@@ -61,8 +61,9 @@ class DirectExchange(ExchangeType):
 
 
 class TopicExchange(ExchangeType):
-    """The `topic` exchanges routes based on words separated by dots, and
-    wildcard characters `*` (any single word), and `#` (one or more words)."""
+    """The `topic` exchange routes messages based on words separated by
+    dots, using wildcard characters ``*`` (any single word), and ``#``
+    (one or more words)."""
     type = "topic"
 
     #: map of wildcard to regex conversions
