@@ -1,3 +1,13 @@
+"""
+kombu.utils
+===========
+
+Internal utilities.
+
+:copyright: (c) 2009 - 2011 by Ask Solem.
+:license: BSD, see LICENSE for more details.
+
+"""
 import sys
 
 from time import sleep
@@ -11,6 +21,21 @@ except:
     ctypes = None  # noqa
 
 
+class HashingDict(dict):
+
+    def __getitem__(self, key):
+        h = hash(key)
+        if h not in self:
+            return self.__missing__(key)
+        return dict.__getitem__(self, h)
+
+    def __setitem__(self, key, value):
+        return dict.__setitem__(self, hash(key), value)
+
+    def __delitem__(self, key):
+        return dict.__delitem__(self, hash(key))
+
+
 def say(m, *s):
     sys.stderr.write(str(m) % s + "\n")
 
@@ -24,13 +49,14 @@ def uuid4():
     return _uuid4()
 
 
-def gen_unique_id():
+def uuid():
     """Generate a unique id, having - hopefully - a very small chance of
     collission.
 
     For now this is provided by :func:`uuid.uuid4`.
     """
     return str(uuid4())
+gen_unique_id = uuid
 
 
 if sys.version_info >= (3, 0):
